@@ -1,6 +1,7 @@
 # import gevent.monkey; gevent.monkey.patch_all()
 import argparse
 import sys
+import os
 
 from . import __version__ as version
 from . import local_device, remote_device, utils, webapp
@@ -10,10 +11,18 @@ from .webapp import views
 
 current_session = DweetSession()
 
+# turn off console output if run as windows GUI
+if sys.executable.endswith("pythonw.exe"):
+    sys.stdout = open(os.devnull, "w")
+    sys.stderr = open(os.path.join(os.getenv("TEMP"), "stderr-"+os.path.basename(sys.argv[0])), "w")
+
+
 def main():
-    arg_parser = argparse.ArgumentParser(description="An interface for networking R232 devices using dweet.io.")
+    arg_parser = argparse.ArgumentParser(
+        description="An interface for networking R232 devices using dweet.io.")
     options = arg_parser.add_mutually_exclusive_group()
-    options.add_argument("--file", type=str, help="Specify config file to use, overriding defaults.")
+    options.add_argument(
+        "--file", type=str, help="Specify config file to use, overriding defaults.")
     options.add_argument("--empty", action='store_true', help="Start dweet2ser with no devices. "
                                                               "Useful for fixing broken config files "
                                                               "or creating new ones.")
@@ -21,7 +30,11 @@ def main():
                          help="Setup a basic connection with command line arguments."
                               "\ne.g. --override DCE /dev/ttyUSB0 dweet2ser_default.")
     arg_parser.add_argument("--nowebui", action="store_true", help="Use dweet2ser from the command line."
-                                                                   "Don't run GUI on webserver.")                          
+                                                                   "Don't run GUI on webserver.")
+    arg_parser.add_argument("--uiport", type=int,
+                            default=5000, help="Port for web interface.")
+    arg_parser.add_argument("--popup", action="store_true",
+                            help="Open a browser window to the web interface on run.")
     args = arg_parser.parse_args()
 
     utils.print_to_ui(f"Starting dweet2ser v{version}...", sys=True)
@@ -32,7 +45,8 @@ def main():
         else:
             other_mode = "DTE"
         try:
-            local = local_device.LocalDevice(args.override[1], args.override[0])
+            local = local_device.LocalDevice(
+                args.override[1], args.override[0])
             remote = remote_device.RemoteDevice(args.override[2], other_mode)
             current_session.bus.add_device(local)
             current_session.bus.add_device(remote)
@@ -49,12 +63,12 @@ def main():
         cli.init(current_session)
         utils.set_ui("cli")
         cli.run()
-    
+
     else:
         views.init(current_session)
         utils.set_ui("webapp")
-        webapp.run()
-    
+        webapp.run(port=args.uiport, popup=args.popup)
+
 
 if __name__ == "__main__":
-    sys.exit(main())
+    main()
