@@ -15,17 +15,20 @@ from . import skiracetiming
 
 colorama_init()
 
+
 class DeviceBus(object):
     """
     Holds all the devices in a connection and facilitates communication between them. All DCE devices
     write to all DTE devices and vice versa.
     """
+
     def __init__(self):
         self.dce_devices = []
         self.dte_devices = []
         self.listen_threads = {}
 
-        self.stream_restarter = threading.Thread(target=self._check_for_crashed_threads)
+        self.stream_restarter = threading.Thread(
+            target=self._check_for_crashed_threads)
         self.stream_restarter.daemon = True
         self.stream_restarter.start()
 
@@ -38,35 +41,51 @@ class DeviceBus(object):
         if device.mode == "DCE":
             self.dce_devices.append(device)
         if not device.mute:
-            self.listen_threads[device.name] = threading.Thread(target=self._listen_stream, args=[device])
+            self.listen_threads[device.name] = threading.Thread(
+                target=self._listen_stream, args=[device])
             self.listen_threads[device.name].daemon = True
             self.listen_threads[device.name].start()
         print_to_ui(f"Added device {device.name}.")
         return True
 
-    def remove_device(self, device_name):
+    def find_device(self, key):
+        for d in self.dce_devices:
+            if d.name == key:
+                return d
+            elif str(d.sku) == key:
+                return d
+        for d in self.dte_devices:
+            if d.name == key:
+                return d
+            elif str(d.sku) == key:
+                return d
+        return None
+
+    def remove_device(self, name_or_sku):
         """
         Takes a device name, and removes that device if the name is found
         """
-        found = False
-        for d in self.dce_devices:
-            if d.name == device_name:
-                found = True
-                d.kill_listen_stream()
-                self.dce_devices.remove(d)
-                TAPES.pop(d.sku, "")
-                print_to_ui(f"Device '{d.name}' removed.")
+        device = self.find_device(name_or_sku)
 
-        for d in self.dte_devices:
-            if d.name == device_name:
-                found = True
-                d.kill_listen_stream()
-                self.dte_devices.remove(d)
-                TAPES.pop(d.sku, "")
-                print_to_ui(f"Device '{d.name}' removed.")
+        if device:
+            device.kill_listen_stream()
+            self.dce_devices.remove(device)
+            TAPES.pop(device.sku, "")
+            print_to_ui(f"Device '{device.name}' removed.")
 
-        if not found:
-            print_to_ui(f"Device {device_name} not found.")
+        else:
+            print_to_ui(f"Device {name_or_sku} not found.")
+
+    def update_translation(self, name_or_sku, translation_list):
+        device = self.find_device(name_or_sku)
+        if device:
+            try:
+                device.translation = translation_list
+                print_to_ui(f"Updated translation for {device.name}: {translation_list}")
+            except Exception as e:
+                print_to_ui(f"Could not update translation for {device.name}: {e}")
+        else:
+            print_to_ui(f"Device {name_or_sku} not found.")
 
     def print_threads(self):
         print_to_ui(self.listen_threads)
@@ -80,24 +99,32 @@ class DeviceBus(object):
         try:
             for message in device.listen():
                 message = str(message)
-                message_decoded = bytes.fromhex(message).decode('latin-1').rstrip().replace('\r', '')
+                message_decoded = bytes.fromhex(message).decode(
+                    'latin-1').rstrip().replace('\r', '')
 
                 print_tape(device.sku, message_decoded)
                 print_to_ui(f"Received {colored(device.type, device.type_color)} message from {device.name}:"
                             f" {Fore.LIGHTWHITE_EX}{message_decoded}{Style.RESET_ALL}")
-                
+
                 if device.translation[0]:
-                    message_decoded = skiracetiming.translate(message_decoded, device.translation[1], 
-                                                            device.translation[2], device.translation[3])
-                    print_to_ui(f"Translated from {device.translation[1]} to {device.translation[2]} "
-                                f"with channel shift {device.translation[3]}.")
-                    message = message_decoded.encode().hex()
-                    
+                    try:
+                        message_decoded = skiracetiming.translate(message_decoded, device.translation[1],
+                                                                  device.translation[2], device.translation[3])
+                        message = message_decoded.encode().hex()
+                        message_decoded = message_decoded.rstrip().replace('\r', '')
+                        print_to_ui(f"Translated from {device.translation[1]} to {device.translation[2]} "
+                                    f"with channel shift {device.translation[3]}.")
+
+                    except Exception as e:
+                        print_to_ui(f"Translation failed: {e}")
+
                 def write_to_device_list(list):
                     for d in list:
                         try:
                             if d.write(message):
-                                print_to_ui(f"{colored(d.type.capitalize(), d.type_color)} message sent to {d.name}: {message_decoded}")
+                                print_to_ui(
+                                    f"{colored(d.type.capitalize(), d.type_color)} message sent to {d.name}: "
+                                    f"{message_decoded}")
                             else:
                                 print_to_ui(f"Writing to {d.name} failed.")
                         except (OSError, ProtocolError, ConnectionError, DweepyError, DeadConnectionError) as e:
@@ -144,15 +171,17 @@ class DeviceBus(object):
 
     def _restart_thread(self, device):
         print_to_ui(f"Reconnecting to {device.name}...")
-        while not internet_connection(): # wait for a connection
+        while not internet_connection():  # wait for a connection
             pass
         time.sleep(1)
-        device.kill_listen_stream()  # attempt to kill the listen thread if it is still responding
+        # attempt to kill the listen thread if it is still responding
+        device.kill_listen_stream()
         device.exc = False  # reset the exception flag to false
         device.restart_session()  # start a new Session
         device.send_message_queue()  # send any messages saved in the queue
         if not device.mute:  # restart the listen thread if needed
-            self.listen_threads[device.name] = threading.Thread(target=self._listen_stream, args=[device])
+            self.listen_threads[device.name] = threading.Thread(
+                target=self._listen_stream, args=[device])
             self.listen_threads[device.name].daemon = True
             self.listen_threads[device.name].start()
         return
