@@ -6,11 +6,13 @@ from serial.serialutil import SerialTimeoutException
 
 from .utils import print_to_ui
 
+
 class LocalDevice(object):
     """
     A device connected to a serial port on the local machine.
     """
-    def __init__(self, port, mode, name="Local Device", mute=False, baudrate=9600, translation = [False, None, None, 0]):
+
+    def __init__(self, port, mode, name="Local Device", mute=False, baudrate=9600, translation=[False, None, None, 0]):
         self.sku = id(self)
         self.name = name
         self.type = "serial"
@@ -20,7 +22,7 @@ class LocalDevice(object):
         self.baudrate = baudrate
         self.serial_port = serial.Serial(port=port,
                                          baudrate=baudrate,
-                                         timeout=0.1,
+                                         timeout=round(1/(baudrate/500), 1),
                                          write_timeout=3)
         self._last_message = ''
         self.mute = mute
@@ -34,10 +36,10 @@ class LocalDevice(object):
         """
         if type(message) is not str:  # make sure the message is a string
             message = str(message)
-        message_bytes = bytes.fromhex(message)  # convert dweet string into bytes for RS232.
+        # convert dweet string into bytes for RS232.
+        message_bytes = bytes.fromhex(message)
         try:
             self.serial_port.write(message_bytes)
-            
             return True
         except SerialTimeoutException:
             return False
@@ -48,7 +50,6 @@ class LocalDevice(object):
         ser = self.serial_port
         self.listening = True
 
-
         while self.listening:
             if ser.in_waiting > 0:
                 ser_data = ser.read(100)
@@ -58,7 +59,7 @@ class LocalDevice(object):
                 time.sleep(0.0001)
         self.serial_port.close()
 
-        return 
+        return
 
     def kill_listen_stream(self):
         """
