@@ -1,12 +1,15 @@
 import datetime
 import threading
 import time
+import uuid
+import os
 
 import requests
 from urllib3.exceptions import ProtocolError
 
 from . import dweepy
-from .utils import internet_connection, print_to_ui
+from .utils import internet_connection, print_to_ui, logger
+
 
 class DeadConnectionError(Exception):
     pass
@@ -16,7 +19,8 @@ class RemoteDevice(object):
     """
     Implementation of a serial device remotely connected with dweet.io
     """
-    def __init__(self, thing_id, mode, thing_key=None, name="Remote Device", mute=False, translation = [False, None, None, 0]):
+    def __init__(self, thing_id, mode, thing_key=None, name="Remote Device",
+                 mute=False, translation=[False, None, None, 0]):
         self.sku = id(self)
         self.name = name
         self.type = "dweet"
@@ -38,7 +42,7 @@ class RemoteDevice(object):
 
         self._session = requests.Session()
         self._last_message = ''
-        self._kill_signal = "kill"
+        self._kill_signal = f"kill {hex(uuid.getnode())}-{os.getpid()}"
         self._message_queue = []
         self._started_on_day = datetime.datetime.utcnow().strftime("%Y-%m-%d")
         self.exc = False
@@ -76,12 +80,13 @@ class RemoteDevice(object):
             return True
 
         except dweepy.DweepyError as e:
-            print_to_ui(str(e))
             if str(e) == "Rate limit exceeded, try again in 1 second(s).":
-                print_to_ui(f"Trying again...")
+                logger.warn(e)
+                logger.info("Trying again...")
                 time.sleep(1.5)
                 return self._send_dweet(content)
             else:
+                print_to_ui(e)
                 return False
 
         except (ConnectionError, ProtocolError, OSError) as e:
@@ -131,7 +136,7 @@ class RemoteDevice(object):
                     if self.read_kw in content:
                         message = content[self.read_kw]
                         if message == self._kill_signal:
-                            print_to_ui(f"Listen stream for {self.name} closed.")
+                            print_to_ui(f"Listen stream for {self.name} killed.")
                             return
                         yield message
 
@@ -159,13 +164,14 @@ class RemoteDevice(object):
         while self.listening and not self.exc:
             no_internet_counter = 0
             for i in range(0, 44):
-                if not self.listening or self.exc:
+                if self.exc or not self.listening:
                     break
                 time.sleep(1)
                 if not internet_connection():
                     no_internet_counter += 1
                 if no_internet_counter >= 3:
                     self.exc = True
+                    print_to_ui("Internet connection lost.")
             self._send_dweet({"keepalive": 1})
 
     def get_last_message(self):
